from django.shortcuts import HttpResponse
from rest_framework.response import Response
from utils.common_logger import logger
from rest_framework.views import APIView
from rest_framework.exceptions import APIException, ValidationError
from utils.common_response import ApiResponse
from rest_framework.viewsets import ViewSet
from rest_framework.decorators import action
from .models import User
from utils.common_response import ApiResponse
from .serializer import UserMulLoginSerializer, UserSmsLoginSerializer, UserRegisterSerializer
from libs.send_tx_sms import get_code, send_sms_by_mobile
from django.core.cache import cache
from threading import Thread


# Create your views here.

# 日志测试
def index(request):
    logger.info('正常查询，稍安勿躁')
    logger.warning('小小警告，不必惊慌')
    logger.error('重视问题，仔细排查')
    logger.critical('紧急情况，不留余力')
    return HttpResponse('ok')


# 全局异常测试,只有继承APIView的视图类才会走全局异常
class ExceptionTestView(APIView):

    def get(self, request):
        # django异常
        # raise Exception('sos!')
        a = [5, ]
        a[99]
        # drf异常
        # raise APIException('api error!')
        # raise ValidationError('validation error!')
        return Response('登陆成功')


# 测试自己封装的响应对象
class ResponseView(APIView):
    def get(self, request):
        # raise APIException({'1':2})
        return ApiResponse(book={'name': '红楼梦', 'price': 33})


class UserView(ViewSet):
    @action(methods=['GET', ], detail=False)
    def check_mobile(self, request, *args, **kwargs):
        try:
            mobile = request.query_params.get('mobile', None)
            User.objects.get(mobile=mobile)  # 有且只有一条才不报错，如果没有或多余一条，就报错
            return ApiResponse(msg='手机号存在')
        except Exception as e:
            raise APIException('手机号不存在')

    @action(methods=['POST', ], detail=False)
    def user_login(self, request, *args, **kwargs):
        return self._common_login(UserMulLoginSerializer, request, *args, **kwargs)

    @action(methods=['GET', ], detail=False)
    def send_sms(self, request, *args, **kwargs):
        mobile = request.query_params.get('mobile', None)
        code = get_code()
        cache.set('send_sms_code_%s' % mobile, code)
        # if mobile and send_sms_by_mobile(mobile, code):
        if mobile:
            t = Thread(target=send_sms_by_mobile, args=(mobile, code))  # 开启一个线程，执行发送短信
            t.start()
            return ApiResponse(msg='消息已发送')
        raise APIException('发送短信出错')

    @action(methods=['POST', ], detail=False)
    def sms_login(self, request, *args, **kwargs):
        return self._common_login(UserSmsLoginSerializer, request, *args, **kwargs, )

    def _common_login(self, serializer, request, *args, **kwargs, ):
        ser = serializer(data=request.data)
        ser.is_valid(raise_exception=True)
        token = ser.context.get('token')
        username = ser.context.get('username')
        icon = ser.context.get('icon')
        return ApiResponse(token=token, username=username, icon=icon)

    @action(methods=['POST'], detail=False)
    def register(self, request, *args, **kwargs):
        ser = UserRegisterSerializer(data=request.data)
        ser.is_valid(raise_exception=True)
        ser.save()
        return ApiResponse(msg="注册成功")
