'''
author:queque
description：这段代码主要作用是从Django项目的settings文件和默认配置文件中获取配置项QUE_SMS，并将其保存到jwt_settings对象中。
'''
# 1 首先import了Django项目的settings文件和默认配置文件
from django.conf import settings
from . import settings as DEFAULTS

# 2 使用getattr函数从Django项目的settings文件中获取QUE_JWT这个配置项，如果不存在，则使用默认配置项{}
USER_SETTINGS = getattr(settings, "QUE_SMS", {})


# 3 接着定义了一个JWTSettings类，用于保存配置项
class SMSSettings:
    # 4 首先在初始化函数中从默认配置文件中获取配置项，并使用setattr函数将其保存到类的属性中。
    def __init__(self):
        # 优先在此处的defaults中获取
        for setting in dir(DEFAULTS):
            if setting.isupper():
                setattr(self, setting, getattr(DEFAULTS, setting))
        # 5 再用django项目中的配置文件覆盖一次,如果django项目中的配置文件中也存在相同的配置项，那么会将其值更新为django项目中的配置项
        for setting in USER_SETTINGS.keys():
            if setting.isupper():
                setattr(self, setting, USER_SETTINGS[setting])


# 6 最后通过类实例化sms_settings对象使用配置项,优先使用django项目中配置的，如果没有，使用此处内置的
sms_settings = SMSSettings()
