# -*- coding: utf-8 -*
from tencentcloud.common import credential
from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
# 导入对应产品模块的client models。
from tencentcloud.sms.v20210111 import sms_client, models

# 导入可选配置类
from tencentcloud.common.profile.client_profile import ClientProfile
from tencentcloud.common.profile.http_profile import HttpProfile
from .setting_manage import sms_settings
import random


# 生成验证码
def get_code(num=4):
    code = ''
    for i in range(num):
        res = random.randint(0, 9)
        code += str(res)  # 强类型，字符串不能加数字

    return code


def send_sms_by_mobile(mobile, code):
    try:
        cred = credential.Credential(sms_settings.SECRET_ID, sms_settings.SECRET_KEY)
        httpProfile = HttpProfile()
        httpProfile.reqMethod = "POST"  # post请求(默认为post请求)
        httpProfile.reqTimeout = 30  # 请求超时时间，单位为秒(默认60秒)
        httpProfile.endpoint = "sms.tencentcloudapi.com"  # 指定接入地域域名(默认就近接入)

        # 非必要步骤:
        # 实例化一个客户端配置对象，可以指定超时时间等配置
        clientProfile = ClientProfile()
        clientProfile.signMethod = "TC3-HMAC-SHA256"  # 指定签名算法
        clientProfile.language = "en-US"
        clientProfile.httpProfile = httpProfile

        # 实例化要请求产品(以sms为例)的client对象
        # 第二个参数是地域信息，可以直接填写字符串ap-guangzhou，支持的地域列表参考 https://cloud.tencent.com/document/api/382/52071#.E5.9C.B0.E5.9F.9F.E5.88.97.E8.A1.A8
        client = sms_client.SmsClient(cred, "ap-guangzhou", clientProfile)
        req = models.SendSmsRequest()
        req.SmsSdkAppId = sms_settings.SMS_SDK_APP_ID
        req.SignName = sms_settings.SIGN_NAME
        req.TemplateId = sms_settings.TEMPLATE_ID
        req.TemplateParamSet = [code, '2']

        req.PhoneNumberSet = ["+86" + mobile]
        # resp是一个HTTP的响应对象
        resp = client.SendSms(req)

        # 输出字典
        res_dict = resp._serialize(allow_none=True)
        if res_dict['SendStatusSet'][0]['Code'] == "Ok":
            return True
        else:
            return False

    except TencentCloudSDKException as err:
        Exception(str(err))  # 记录日志
        return False
