from rest_framework.views import exception_handler
from rest_framework.response import Response
from utils.common_logger import logger


# 加入日志，记录ip、用户id、请求地址、视图函数,执行错误
def common_exception_handler(exc, context):
    res = exception_handler(exc, context)
    request = context.get('request')
    ip = request.META.get('REMOTE_ADDR')
    user_id = request.user.pk
    path = request.get_full_path()
    view = str(context.get('view'))
    logger.error('ip为[%s]，用户id[%s]，由请求地址[%s]，执行视图函数[%s]，错误是[%s]' % (ip, user_id, path, view, str(exc)))
    if res:
        # drf 的异常有2种情况，一种是从res.data字典的detail中取，一种是直接取
        if isinstance(res.data, dict):
            if not res.data.get('detail'):
                data = {'code': 202, 'msg': res.data}  # 异常是字典
                return Response(data)
            data = {'code': 202, 'msg': res.data.get('detail')}  # 异常是字符串
        else:
            data = {'code': 203, 'msg': res.data}  # 异常是列表
        return Response(data)
    else:
        # django的异常
        data = {'code': 201, 'msg': str(exc)}
        return Response(data)
